===================================
Mahotas: Image Processing for numpy
===================================

Jump to full `API Documentation <api.html>`__

Contents:

.. toctree::
   :maxdepth: 2

   features
   surf
   thresholding
   distance
   labeled
   polygon
   classification
   faq
   internals
   principles
   api


.. include:: readme.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
